@@ -18,7 +18,7 @@
  *
  * The author may be contacted via http://dmalloc.com/
  *
- * $Id: dmalloc.c,v 1.114 2004/07/10 03:49:52 gray Exp $
+ * $Id: dmalloc.c,v 1.119 2006/03/26 18:29:39 gray Exp $
  */
 
 /*
@@ -36,8 +36,6 @@
 
 #define DMALLOC_DISABLE
 
-#include "dmalloc_argv.h"			/* for argument processing */
-
 #if HAVE_STRING_H
 # include <string.h>
 #endif
@@ -46,6 +44,7 @@
 #endif
 
 #include "conf.h"
+#include "dmalloc_argv.h"			/* for argument processing */
 #include "dmalloc.h"
 
 #include "compat.h"
@@ -141,6 +140,7 @@ static	unsigned long start_size = 0;		/* for START settings */
 static	int	usage_b = 0;			/* usage messages */
 static	int	verbose_b = 0;			/* verbose flag */
 static	int	very_verbose_b = 0;		/* very-verbose flag */
+static	int	version_b = 0;			/* print version string */
 static	char	*tag = NULL;			/* maybe a tag argument */
 
 static	argv_t	args[] = {
@@ -156,9 +156,6 @@ static	argv_t	args[] = {
   { 'R',	"rc-shell",	ARGV_BOOL_INT,	&rcshell_b,
     NULL,			"set output for rc shell" },
   
-  { 'L',	"long-tokens",	ARGV_BOOL_INT,	&long_tokens_b,
-    NULL,			"output long-tokens not 0x..." },
-  
   { 'a',	"address",	ARGV_CHAR_P,	&address,
     "address:#",		"stop when malloc sees address" },
   { 'c',	"clear",	ARGV_BOOL_INT,	&clear_b,
@@ -179,6 +176,8 @@ static	argv_t	args[] = {
     NULL,			"keep settings (override -r)" },
   { 'l',	"logfile",	ARGV_CHAR_P,	&logpath,
     "path",			"file to log messages to" },
+  { 'L',	"long-tokens",	ARGV_BOOL_INT,	&long_tokens_b,
+    NULL,			"set env with tokens not 0x..." },
   { 'm',	"minus",	ARGV_CHAR_P | ARGV_FLAG_ARRAY,	&minus,
     "token(s)",			"del tokens from current debug" },
   { LIMIT_ARG,	"memory-limit",	ARGV_U_SIZE,	&limit_arg,
@@ -209,8 +208,10 @@ static	argv_t	args[] = {
     NULL,			"turn on verbose output" },
   { 'V',	"very-verbose",	ARGV_BOOL_INT,	&very_verbose_b,
     NULL,			"turn on very-verbose output" },
+  { '\0',	"version",	ARGV_BOOL_INT,	&version_b,
+    NULL,			"display version string" },
   { ARGV_MAYBE,	NULL,		ARGV_CHAR_P,	&tag,
-    "tag",			"debug token to find in rc" },
+    "tag",			"debug token, internal or from rc file" },
   { ARGV_LAST }
 };
 
@@ -874,6 +875,8 @@ int	main(int argc, char **argv)
   
   argv_help_string = "Sets dmalloc library env variables.  Also try --usage.";
   argv_version_string = dmalloc_version;
+  argv_usage_type = ARGV_USAGE_LONG;
+  argv_error_type = ARGV_USAGE_SHORT_REM;
   
   argv_process(args, argc, argv);
   
@@ -886,7 +889,16 @@ int	main(int argc, char **argv)
   }
   if (usage_b) {
     header();
-    argv_usage(args, ARGV_USAGE_ALL);
+    argv_usage(args, argv_usage_type);
+    exit(0);
+  }
+  if (version_b) {
+    (void)fprintf(stderr, "Dmalloc utility version string is: %s\n",
+		  argv_version_string);
+    (void)fprintf(stderr,
+		  "  NOTE: Library linked with your application may be a different version.\n");
+    (void)fprintf(stderr,
+		  "        Check top of logfile after application is run for library version.\n");
     exit(0);
   }
   
